#!/usr/bin/env python

"""
===============================================================
    Module for testing of structure class
===============================================================
"""


from time import *
import sys
from ScriboExc import WarningExc

import Misc
import random

import unittest
__author__ = "Sannikov Alexander <sannikov@cs.karelia.ru>"
__version__ = "$Revision: 0.1 $"
__date__ = "$Date: 2010/01/27 $"
__copyright__ = ""
__license__ = "GPLv2"

class MiscTest(unittest.TestCase):
     def testget(self):
         d1 = {0:0, 1:10, 2:20, 3:30, 4:40, 5:50, 6:60, 7:70, 8:80, 9:90}
         Misc._services = d1

         for i in xrange(1, 10):
             Misc._services[i] = d1
         for i in xrange(1, 10):
             tmp = Misc.services(i)
             self.assertEqual(len(tmp), len(d1))
             for j in d1.keys():
                 self.assertEqual(tmp[j], d1[j])


     def testadd(self):
         Misc._services = None
         d1 = {
               'icon': '../data/faviconLJ.ico',
                'name': 'LiveJournal'
             }
         r = Misc.services("lj")
         for i in d1.keys():
             self.assertEqual(d1[i], r[i])


if __name__ == '__main__':
    testSuite = unittest.TestLoader().loadTestsFromTestCase(MiscTest)
    text_runner = unittest.TextTestRunner(verbosity=2).run(testSuite)
